EOFBootstrapper
===============

.. currentmodule:: xeofs.validation

.. autoclass:: EOFBootstrapper
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EOFBootstrapper.__init__
      ~EOFBootstrapper.components
      ~EOFBootstrapper.compute
      ~EOFBootstrapper.deserialize
      ~EOFBootstrapper.explained_variance
      ~EOFBootstrapper.explained_variance_ratio
      ~EOFBootstrapper.fit
      ~EOFBootstrapper.fit_transform
      ~EOFBootstrapper.get_params
      ~EOFBootstrapper.get_serialization_attrs
      ~EOFBootstrapper.inverse_transform
      ~EOFBootstrapper.load
      ~EOFBootstrapper.save
      ~EOFBootstrapper.scores
      ~EOFBootstrapper.serialize
      ~EOFBootstrapper.singular_values
      ~EOFBootstrapper.transform
   
   

   
   
   